@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['objects_0',['objects',['../page_tutorial2.html',1,'Tutorial - Part 2: Enumerating Objects'],['../page_tutorial6.html',1,'Tutorial - Part 6: Binding Objects']]],
+  ['objects_0',['Objects',['../page_tutorial2.html',1,'Tutorial - Part 2: Enumerating Objects'],['../page_tutorial6.html',1,'Tutorial - Part 6: Binding Objects']]],
   ['objects_20design_1',['Objects Design',['../page_objects_design.html',1,'page_internals']]],
   ['of_20example_20programs_2',['List of example programs',['../page_examples.html',1,'page_tutorial']]],
   ['on_20connect_3',['Switch on Connect',['../page_pulse_module_switch_on_connect.html',1,'page_pulse_modules']]],
